@@ -230,10 +230,10 @@ class HistoryAlias(xcli.ArgParserAlias):
             str, xcli.Arg(nargs="?", action=SessionAction)
         ] = "session",
         slices: xcli.Annotated[list[int], xcli.Arg(nargs="*")] = None,
-        datetime_format: tp.Optional[str] = None,
-        start_time: tp.Optional[str] = None,
-        end_time: tp.Optional[str] = None,
-        location: tp.Optional[str] = None,
+        datetime_format: str | None = None,
+        start_time: str | None = None,
+        end_time: str | None = None,
+        location: str | None = None,
         reverse=False,
         numerate=False,
         timestamp=False,
